## v2.1.0
* (Patch) Remove dependency on _app_ctx_stack
* (Minor) Refactor `Flask-Unleash` to modernize tooling (`setuptools_scm` and centralizing tool config in `pyproject.toml`).
* (Minor) Migrate documentation to Sphinx.

## v2.0.0
* (Major) Loosen UnleashClient requirement.
* (Major) Update config to support UnleashClient v5.0.0 initialization arguments.
* (Minor) Adds security code scanning.

## v1.0.2

**General**

* (Major) Move CI to Github Actions.

## v1.0.1

**General**

* (Major) Update handling of optional configuration so defaults come from main unleash-client-python.

## v1.0.0

**General**

* First implementation of the Flask-Unleash plugin!  Woo!